# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative 'lib/gravaty/version'

SUMMARY = 'This gem automagically prepares complete URIs for Gravatar,
 for both avatars and profiles, with all currently supported options,
 included the XML-RPC API, as of 2014-04-30, starting from a single
 email address!'

COMMON_FILES = %w[CHANGELOG COPYING.md copyright.md Gemfile
                  gravaty.gemspec gravaty.odp gravaty.pdf Rakefile README.md]

Gem::Specification.new do |a_gem|
  a_gem.name = 'gravaty'
  a_gem.version = Gravaty::VERSION
  a_gem.license = 'GPL-3.0'
  a_gem.licenses = %w[GPL-3.0 BSD-3-Clause]
  a_gem.author = 'Marco Bresciani'
  a_gem.authors = ['Marco Bresciani', '新部裕', 'Peter R. Marreck',
                   'Jon Maken', 'Łukasz Niemier']
  a_gem.email = 'marcobresciani_1974@libero.it'
  a_gem.homepage = "https://savannah.nongnu.org/projects/#{a_gem.name}/"
  a_gem.summary = SUMMARY
  a_gem.description = "#{SUMMARY} It's my first Ruby gem, hoping it will
be useful for someone (let me know if you use it, please!).
GNU GPLv3 license; source code available through anonymous checkout: `hg
clone http://hg.savannah.nongnu.org/hgweb/#{a_gem.name}/` or write me
and I'll send it.
You can even decide to contribute to this little free software project
by registering to Savannah and ask to be part of the '#{a_gem.name}'
project!
With contributions from: 新部裕, Peter R. Marreck, Jon Maken, Łukasz
Niemier."
  a_gem.metadata = {
    'homepage_uri' => "https://savannah.nongnu.org/projects/#{a_gem.name}",
    'changelog_uri' => "http://hg.savannah.nongnu.org/hgweb/#{a_gem.name}/file/tip/CHANGELOG",
    'source_code_uri' => "http://hg.savannah.nongnu.org/hgweb/#{a_gem.name}/file/",
    'bug_tracker_uri' => "https://savannah.nongnu.org/bugs/?group=#{a_gem.name}",
    'documentation_uri' => "http://hg.savannah.nongnu.org/hgweb/#{a_gem.name}/tag/#{a_gem.version}/"
    # 'mailing_list_uri' => 'https://groups.example.com/bestgemever',
    # 'wiki_uri' => 'https://example.com/user/bestgemever/wiki'
  }

  a_gem.files = Dir.glob('{examples,html,lib,test}/**/*') + COMMON_FILES
  a_gem.test_files = Dir.glob('test/**/test_*.rb')
  a_gem.require_path = 'lib'
  a_gem.require_paths = %w[lib]
  a_gem.extra_rdoc_files = COMMON_FILES

  a_gem.required_ruby_version = '~> 3.0'
  a_gem.rubygems_version = '~> 3.0'

  a_gem.add_runtime_dependency 'i18n', '~>1.8'
  a_gem.add_runtime_dependency 'json', '~>2.5'
  a_gem.add_runtime_dependency 'xmlrpc', '~>0.3.1'

  a_gem.add_development_dependency 'bundler', '~>2.1'
  a_gem.add_development_dependency 'minitest', '~>5.14'
  a_gem.add_development_dependency 'rake', '~>13.0'
  a_gem.add_development_dependency 'rdoc', '~>6.3'
  a_gem.add_development_dependency 'rubocop', '~>1.8'
  a_gem.add_development_dependency 'simplecov', '~>0.21'

  a_gem.requirements = a_gem.required_ruby_version.to_s, a_gem.dependencies.to_s

  a_gem.post_install_message = begin
    require 'changelog'
  rescue LoadError
    "Thank you for using #{a_gem.name} version #{a_gem.version}."
                               else
                                 CHANGELOG.new.version_changes
  end
end
