# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../test_helper'

describe Gravaty::Gravaty do
  describe 'when using a parser ' do
    subject { Gravaty.parser }

    it 'shall provide a list of parsers' do
      _(subject.parsers).wont_be_empty
    end

    it 'shall provide all needed parsers' do
      _(subject.parsers.length).must_equal Gravaty::ALLOWED_PARAMS.length
      _(subject.parsers.keys).must_equal Gravaty::ALLOWED_PARAMS
    end

    it 'shall use the parsable duck type' do
      parsable_mocks = {}

      Gravaty::ALLOWED_PARAMS.each do |param|
        parsable_mocks[param] = MiniTest::Mock.new
        parsable_mocks[param].expect(:parse, false, [nil])
      end

      my_parser = Gravaty::Parser.new(parsable_mocks)

      Gravaty::ALLOWED_PARAMS.each do |param|
        my_parser.parse param
        parsable_mocks[param].verify
      end
    end

    it 'shall die gracefully whether parameters are not valid' do
      a_parser = Gravaty::Parser.new(nil)
      a_parser.parse
    end
  end
end
