# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../../test_helper'

describe Gravaty::Utils::Downloader do
  describe 'when passed a nil uri' do
    it 'must raise a RuntimeError' do
      _(lambda {
        Gravaty::Utils::Downloader::Downloader
          .download_file nil, 'filename'
      })
        .must_raise RuntimeError
    end
  end

  describe 'when passed an invalid uri' do
    it 'must raise a InvalidURIError' do
      _(lambda {
        Gravaty::Utils::Downloader::Downloader
          .download_file 'http://example.com/%uABCD',
                         'filename'
      })
        .must_raise URI::InvalidURIError
    end
  end

  describe 'when passed a nil filename' do
    it 'must raise a TypeError' do
      _(lambda {
        Gravaty::Utils::Downloader::Downloader
          .download_file 'http://www.example.com',
                         nil
      }).must_raise TypeError
    end
  end

  http_file = 'wget-latest.tar.gz'
  download_url = 'ftp.jaist.ac.jp/pub/GNU/wget/'

  describe 'when passed a valid HTTP filename' do
    it 'must download a proper file' do
      Gravaty::Utils::Downloader::Downloader
        .download_file "http://#{download_url}",
                       http_file
      _(File.exist?(http_file)).must_equal(true)
      File.delete http_file
      _(File.exist?(http_file)).must_equal(false)
    end
  end

  describe 'when passed a valid HTTPS filename' do
    if ENV['SSL_CERT_FILE']
      it 'must download a proper file' do
        # https_file = 'wget-latest.tar.gz'
        Gravaty::Utils::Downloader::Downloader
          .download_file "https://#{download_url}",
                         https_file
        _(File.exist?(https_file)).must_equal(true)
        File.delete https_file
        _(File.exist?(https_file)).must_equal(false)
      end
    end
  end
end
