# frozen_string_literal: true

#--
# gravaty
# rubocop:disable Style/AsciiComments
# © 2013 Marco Bresciani
# rubocop:enable Style/AsciiComments
#
# This file is part of gravaty.
#
# gravaty is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# gravaty is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with gravaty. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2013 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../../test_helper'

def test_digest(param, password)
  it "shall raise an ArgumentError when digest is '#{param}'" do
    _(lambda {
      Gravaty::Utils::RpcConnector::RpcConnector
        .new param, password
    }).must_raise ArgumentError
  end
end

def test_password(digest, param)
  it "shall raise an ArgumentError when password is '#{param}'" do
    _(lambda {
      Gravaty::Utils::RpcConnector::RpcConnector
        .new digest, param
    }).must_raise ArgumentError
  end
end

def test_parameters(param)
  it "shall raise an ArgumentError when parameters are '#{param}'" do
    _(lambda {
      Gravaty::Utils::RpcConnector::RpcConnector
        .new param, param
    }).must_raise ArgumentError
  end
end

def test_invalid_parameter(digest, password)
  describe 'when receiving an invalid parameter' do
    [nil, ''].each do |param|
      test_digest(param, password)

      test_password(digest, param)

      test_parameters(param)
    end
  end
end

def test_info_test
  it 'shall provide information through test method' do
    skip 'This test shall be configured with own Gravatar email and password.'
    result = subject.call(Gravaty::RPC_TEST_METHOD)

    result.wont_be_nil
    result.wont_be_empty
    result['response'].wont_be_nil
  end
end

def test_info_exist(digest)
  it 'shall provide information through exists method' do
    skip 'This test shall be configured with own Gravatar email and password.'
    result = subject.call('grav.exists', hashes: [digest])

    result.wont_be_nil
    result.wont_be_empty
    result[digest].wont_be_nil
  end
end

def test_valid_parameter(digest)
  describe 'when created with valid parameters' do
    it 'shall provide an useable connector' do
      _(subject).wont_be_nil
    end

    test_info_test

    test_info_exist(digest)
  end
end

describe Gravaty::Utils::RpcConnector do
  before do
    I18n.load_path = Dir[File.join(File.dirname(__FILE__),
                                   '/../../../lib/gravaty/locales/',
                                   '*.yml')]
    I18n.locale = 'it'
  end

  digest = Digest::MD5.hexdigest('[YOUR EMAIL HERE]'.downcase)
  password = '[YOUR PASSWORD HERE]'

  subject do
    Gravaty::Utils::RpcConnector::RpcConnector
      .new digest, password
  end

  test_invalid_parameter(digest, password)

  test_valid_parameter(digest)
end
